@@ -129,6 +129,9 @@ private slots:
     void onSigMosquittoChanges(bool bEnable, const QString &host, int port,
                                const QString &topic);
 
+    //! Activated when the user saves the GV pin
+    void onSigPinSettingChanges(bool bEnable, const QString &pin);
+
     void onMqThreadFinished();
 
     //! Invoked when the message box is done
@@ -140,6 +143,9 @@ private slots:
     //! Invoked when the timer based cleanup of logs array is invoked
     void onCleanupLogsArray();
 
+    //! Invoked when the call is completed on fallback
+    void onFallbackDialout (bool bSuccess, void *v_ctx);
+
 private:
     void initLogging ();
 
@@ -170,6 +176,8 @@ private:
     void setUsername(const QString &strUsername);
     void setPassword(const QString &strPassword);
 
+    void fallbackDialout (DialContext *ctx);
+
 private:
     //! Logfile
     QFile           fLogfile;
@@ -177,9 +185,9 @@ private:
     // Tray, icons, widgets
     QIcon           icoGoogle;
     QSystemTrayIcon *pSystray;
-    //! Contacts table widget
+    //! GV Contacts object
     GVContactsTable oContacts;
-    //! Contacts table widget
+    //! GV Inbox object
     GVInbox         oInbox;
     //! SMS Window
     SMSDlg          dlgSMS;
@@ -214,6 +222,9 @@ private:
     //! Index of the registered phone currently in use
     int             indRegPhone;
 
+    //! GV PIN for the fallback method
+    QString         strGvPin;
+
 ///////////////////////////////////////////////////////////////////////////////
 // This block of variable is protected by the one mutex in it
 ///////////////////////////////////////////////////////////////////////////////
